@@ -44,6 +44,7 @@ bal.table.mediation <-
     w_10 <- attr(x, "w_10")
     w_01 <- attr(x, "w_01")
     w_11 <- attr(x, "w_11")
+    sampw <- attr(x,"sampw")
     column_names <- colnames(data)
     m_and_x_names <- c(x$mediator_names,x$covariate_names)
     
@@ -115,6 +116,11 @@ bal.table.mediation <-
     balance_res[["check_counterfactual_nie_1"]] <- balance_nie_1 
     balance_res[["check_counterfactual_nie_0"]] <- balance_nie_0
     
+    if(!is.null(sampw)) {
+	attr(balance_res,"sampw") <- TRUE
+    } else {
+	attr(balance_res,"sampw") <- FALSE
+    }
     attr(balance_res, "class") <- "bal.table.mediation"
     
     if(details){
@@ -148,8 +154,8 @@ bal.table.mediation <-
         wts_a <- ifelse(data[,x$a_treatment]==1,1/model_a_preds,1/(1-model_a_preds))
         
         tmp_a <- bal.table.ps(dx.wts.mediation(wts_a, data = data, 
-                                               vars = x$covariate_names, treat.var = x$a_treatment, x.as.weights = TRUE, 
-                                               estimand = "ATE"),digits=digits)
+                                               vars = x$covariate_names[!x$covariate_names %in% x$med_interactions], treat.var = x$a_treatment, x.as.weights = TRUE, 
+                                               estimand = "ATE",sampw=sampw),digits=digits)
         names(tmp_a)[2] <- x$method
         balance_a <- do.call(rbind, tmp_a)
         balance_a['model'] <- 'Model A'
@@ -166,7 +172,7 @@ bal.table.mediation <-
         wts_m0 <- ifelse(data[,x$a_treatment]==0,1,1/exp(model_m_preds))
         tmp_m0 <- dx.wts.mediation(wts_m0, data = data, 
                                    vars = m_and_x_names, treat.var = "trt0", x.as.weights = TRUE, 
-                                   estimand = "ATT")
+                                   estimand = "ATT",sampw=sampw)
         tmp_m0$desc <- lapply(tmp_m0$desc, swapTxCtrl)
         tmp_m0 <- bal.table.ps(tmp_m0, digits=digits)
         names(tmp_m0)[2] <- x$method
@@ -177,7 +183,7 @@ bal.table.mediation <-
         wts_m1 <- ifelse(data[,x$a_treatment]==0,exp(model_m_preds),1)
         tmp_m1 <- bal.table.ps(dx.wts.mediation(wts_m1, data = data, 
                                                 vars = m_and_x_names, treat.var = x$a_treatment, x.as.weights = TRUE, 
-                                                estimand = "ATT"),digits=digits)
+                                                estimand = "ATT",sampw=sampw),digits=digits)
         names(tmp_m1)[2] <- x$method
         balance_m1<- do.call(rbind, tmp_m1)
         balance_m1["model"] <- "Model M1"
@@ -196,7 +202,30 @@ bal.table.mediation <-
       details  <- list(balance_a = balance_a, balance_m0 = balance_m0,balance_m1 = balance_m1) 
       
       attr(details, "note") <- "**********************************************************\nNotes: \nA. Model A estimates the probability of exposure given \nthe covariates specified in wgtmed. The results are used \nby wgtmed to estimate E[Y(1,M(0))] and E[Y(0,M(1))]. \nThey are not used to estimate the total effect. \nB. Model M0 is used for NDE_0 and NIE_1 effects. \nct.sd is used for the denominator of std.eff.sz. \nC. Model M1 is used for NDE_1 and NIE_0 effects.\ntx.sd is used for the denominator of std.eff.sz. \nSee the bal.table.mediation help file for more information. \n**********************************************************\n"
-      
+      if(!is.null(sampw)) {
+
+        methodnms <- names(balance_res$NIE1)
+        if(length(methodnms)==1) { 
+		methods <- paste0("\"",methodnms,"\" reflects")
+	} 
+	if(length(methodnms)==2) {
+		methods <- character()
+        	for(i in methodnms) {
+        		methods <- c(methods,paste0("\"",i,"\""))
+		}
+		methods <- paste(paste(methods,collapse=" and "),"relfect")
+	}
+	if(length(methodnms)>2) {
+		methods <- character()
+        	for(i in methodnms[1:(length(methodnms)-1)]) {
+        		methods <- c(methods,paste0("\"",i,"\""))
+		}
+		methods <- paste0(paste(methods,collapse=", "),", and \"",methodnms[length(methodnms)],"\" reflect")
+	}
+
+ 	attr(details, "note") <- paste0("**********************************************************\nNotes: \nA. Model A estimates the probability of exposure given \nthe covariates specified in wgtmed. The results are used \nby wgtmed to estimate E[Y(1,M(0))] and E[Y(0,M(1))]. \nThey are not used to estimate the total effect. \nB. Model M0 is used for NDE_0 and NIE_1 effects. \nct.sd is used for the denominator of std.eff.sz. \nC. Model M1 is used for NDE_1 and NIE_0 effects.\ntx.sd is used for the denominator of std.eff.sz. \nD. \"unw\" reflects weighting with sampling weights \nonly. ",methods," weighting by both \nthe sampling weights and total-effect/cross-world weights.\nSee the bal.table.mediation help file for more information. \n**********************************************************\n")
+      }     
+
       balance_res[["details"]] <- details
       
     } ## Ends if details
@@ -214,7 +243,7 @@ bal.table.mediation <-
        cov_plots <- vector("list",length(stopping_methods))
        for(k in 1:length(stopping_methods)) {
          allbal <- Allbal[Allbal$type %in% c("unw","ps",stopping_methods[k]),]
-         allbal$covariate <- factor(allbal$covariate,levels=rownames(balance_res$TE[[1]]))
+         allbal$covariate <- factor(allbal$covariate,levels=rownames(balance_res$NDE0[[1]]))
          allbal$Effect <- factor(allbal$Effect,levels=c("NDE0","NDE1","TE","NIE0","NIE1"))
          allbal$type2 <- ifelse(allbal$type=="unw","unweighted","weighted")  
 
